//BUNDLE JOB (BUNDLE),CLASS=A,MSGCLASS=H,
//   MSGLEVEL=(1,1),NOTIFY=&SYSUID
//*******************************************************************
//**   Licensed Materials - Property of IBM and/or HCL
//**   (c) Copyright IBM Corporation 2005, 2021. All Rights Reserved.
//**   (c) Copyright HCL Technologies Ltd. 2017,2021. All Rights Reserved.
//**
//**   Note to U.S. Government Users Restricted Rights:
//**   Use, duplication or disclosure restricted by GSA ADP Schedule
//**   Contract with IBM Corp.
//**
//* Sample JCL to execute the bundle_pacs_multi map using the 
//* Transformation Extender Command Server for z/OS (OS/390).
//*
//**********************************************************************
//  SET DTXLIB=DSTX.REL8102.BLD00.LOADLIB      <== DSTX LOAD LIB
//  SET MAPLIB=TXUSER.DSTX830.MAPLIB(PROCESS)  <== DSTX MAP DSN
//  SET MAPINP1=TXUSER.BUNDLE.MSGLIST          <== INPUT1 FILE DSN
//  SET UNIT=SYSDA                             <== WORKFILE UNIT
//  SET LRECL=32760                            <== WORKFILE LRECL
//  SET CLASS=*                                <== SYSOUT CLASS
//**********************************************************************
//**
//**   This is the main map section which calls the map
//**
//**********************************************************************
//DTX     EXEC PGM=DTXCMDSV,REGION=0M,
//  PARM='-@CMDFILE'
//         DD  DISP=SHR,DSN=&DTXLIB
//CMDFILE  DD  *
 MAPIN -IF1 IN1 -AE -TIO
/*
//***********************************************************************
//**
//**   This is the main map section which calls the top level map for a
//**   EBA STEP2 message bundle. Also includes references for all  runmaps
//**   called from the main map
//**
//***********************************************************************
//MAPIN    DD  DISP=SHR,DSN=&MAPLIB
//MKFILES  DD DSN=TXUSER.DSTX830.MAPLIB(MKFILES),DISP=SHR
//APPEND   DD DSN=TXUSER.DSTX830.MAPLIB(APPEND),DISP=SHR
//ASSEMBLE DD DSN=TXUSER.DSTX830.MAPLIB(ASSEMBLE),DISP=SHR
//**********************************************************************
//**
//**    These are the references to the input and output files needed by
//**    the run maps.
//**    MAPINP1 refers to the list of datasets to be processed
//**    The EBABULK output will contain the EBA bundle
//**    FILESIZE is created to track the individual bundle sizes
//**    COUNTERS is created to keep counts of each message type
//**    NOTE: DISP for the FILESIZE, COUNTERS, TMP8, TMP6, TMP4
//**    files needs to be changed to NEW or SHR depending on
//**    whether the file previously existed or not
//**
//**********************************************************************
//IN1      DD  DISP=SHR,DSN=&MAPINP1
//PACS041  DD DSN=TXUSER.PACS041,DISP=SHR
//PACS042  DD DSN=TXUSER.PACS042,DISP=SHR
//PACS081  DD DSN=TXUSER.PACS081,DISP=SHR
//PACS082  DD DSN=TXUSER.PACS082,DISP=SHR
//FILESIZE DD DSN=TXUSER.BUNDLE.FILESIZE,
//            DISP=SHR,
//            DCB=(RECFM=VB,LRECL=80),
//            UNIT=SYSDA,
//            SPACE=(TRK,(5,2),RLSE)
//COUNTERS DD DSN=TXUSER.BUNDLE.COUNTERS,
//            DISP=SHR,
//            DCB=(RECFM=VB,LRECL=80),
//            UNIT=SYSDA,
//            SPACE=(TRK,(5,2),RLSE)
//CONFIG   DD DSN=TXUSER.BUNDLE.CONFIG,
//            DISP=SHR,
//            DCB=(RECFM=VB,LRECL=80),
//            UNIT=SYSDA,
//            SPACE=(TRK,(5,2),RLSE)
//TMP8     DD DSN=TXUSER.BUNDLE.TMP8,
//            DISP=SHR,
//            DCB=(RECFM=VB,LRECL=80),
//            UNIT=SYSDA,
//            SPACE=(TRK,(5,2),RLSE)
//TMP4     DD DSN=TXUSER.BUNDLE.TMP4,
//            DISP=SHR,
//            DCB=(RECFM=VB,LRECL=80),
//            UNIT=SYSDA,
//            SPACE=(TRK,(5,2),RLSE)
//EBABULK  DD DSN=TXUSER.BUNDLE.EBABULK,
//            DISP=(MOD,CATLG,DELETE),
//            DCB=(RECFM=VB,LRECL=80),
//            UNIT=SYSDA,
//            SPACE=(TRK,(5,2),RLSE)
//**********************************************************************
//**
//**   Static temporary dataset allocations
//**
//**********************************************************************
//DSTXLOG  DD  SYSOUT=&CLASS             Execution log
//DSTXAUD  DD  SYSOUT=&CLASS             Audit file
//DSTXTRCE DD  SYSOUT=&CLASS             Trace file
//SYSPRINT DD  SYSOUT=&CLASS
//SYSOUT   DD  SYSOUT=&CLASS
//CEEDUMP  DD  SYSOUT=&CLASS
//IDIOFF   DD  DUMMY
//**********************************************************************
//**
//**   Static temporary dataset allocations
//**
//**********************************************************************
//SYSTMP01 DD DSN=&&TEMP01,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP02 DD DSN=&&TEMP02,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP03 DD DSN=&&TEMP03,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP04 DD DSN=&&TEMP04,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP05 DD DSN=&&TEMP05,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP06 DD DSN=&&TEMP06,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP07 DD DSN=&&TEMP07,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP08 DD DSN=&&TEMP08,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP09 DD DSN=&&TEMP09,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP10 DD DSN=&&TEMP10,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP11 DD DSN=&&TEMP11,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP12 DD DSN=&&TEMP12,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP13 DD DSN=&&TEMP13,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP14 DD DSN=&&TEMP14,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP15 DD DSN=&&TEMP15,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//SYSTMP16 DD DSN=&&TEMP16,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
