//*********************************************************************
//**   Licensed Materials - Property of IBM and/or HCL 
//**   (c) Copyright IBM Corporation 2005, 2021. All Rights Reserved. 
//**   (c) Copyright HCL Technologies Ltd. 2017, 2021. All Rights Reserved. 
//**                                                             
//**   Note to U.S. Government Users Restricted Rights: 
//**   Use, duplication or disclosure restricted by GSA ADP Schedule 
//**   Contract with IBM Corp.
//**
//**         SEPA VALIDATION
//**
//**   This is a sample JCL to assist with the execution of a SEPA
//**   message validation in Z/OS. This is a passthrough example
//**   JCl for validating a pacs_008_001_02 message, using the
//**   pacs_008_001_02.xsd schema.
//**   Prior to executing this JCL, the type tree associated to
//**   the schema needs to be modified to add the schema DD name
//**   in the Doc Intent Location. As an example, for this message
//**   the type tree pacs.008.001.02_mvs.mtt was changed to have in
//**   the Intent Location the following value:
//**   //DD:PC812XSD
//**   The compiled map and schema then need to be ported as
//**   binary files to the library where they will reside for
//**   their use. In this example, both the map PACS008C and the
//**   schema (dd name PC812XSD) are ported to the Mydir.SEPA.MAPLIB
//**   folder.
//**   The input card is overriden by the DDNAME INPAC008
//**
//**   The program to be executed is DTXCMDSV,
//**   the command line is passed through the PARM statement which
//**   which contains the execution commands required to run
//**   the passthrough map.
//**
//**
//**********************************************************************
//**
//STEP1 EXEC PGM=DTXCMDSV,REGION=0M,
//           PARM='MAPDDS /P256:12 -IF1 INPAC008'
//**********************************************************************
//**   Load libraries for TX and where all the maps and schemas reside
//**
//**********************************************************************
//STEPLIB DD DSN=DSTX.DTX830.BLD00.XPL.LOADLIB,DISP=SHR
//        DD DSN=TXUSER.WTX.MAPLIB,DISP=SHR
//***********************************************************************
//**
//**   This is the main map section which calls the passthrough map for
//**   SEPA message PACS.008
//**
//***********************************************************************
//MAPDDS DD DSN=TXUSER.SEPA.MAPLIB(PACS008C),DISP=SHR
//**********************************************************************
//**
//**   These are the references to the schemas that are used in the
//**   validation of the SEPA data. They need to reside in the same
//**   dataset as the maps. The schema pacs.008.001.002.xsd is
//**   ported to Z/os  as name PC812XSD for this example.
//**
//**********************************************************************
//PACS008C DD DSN=TXUSER.SEPA.MAPLIB(PACS008C),DISP=SHR
//**********************************************************************
//**
//**    These are the references to the input and output files as
//**    defined in the PARMS command file
//**
//**********************************************************************
//INPAC008   DD DSN=TXUSER.PAC8TEST.XML,DISP=SHR,
//            DCB=(RECFM=VB,LRECL=256),
//            UNIT=SYSDA,SPACE=(TRK,(5,1))
//**********************************************************************
//PC812XSD   DD DSN=TXUSER.PAC8TEST.XSD(PACS812),DISP=SHR
//**********************************************************************
//**
//**   Trace and log files
//**
//**********************************************************************
//DTXLOG DD SYSOUT=*
//DTXAUD DD SYSOUT=*
//DTXTRCE DD SYSOUT=*
//SYSPRINT DD SYSOUT=*
//SYSOUT DD SYSOUT=*
//CEEDUMP DD SYSOUT=*
//**********************************************************************
//**
//**   Static temporary dataset allocations
//**
//**********************************************************************
//SYSTMP01 DD DSN=&&TEMP01,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=VIO,SPACE=(TRK,(5,1))
//SYSTMP02 DD DSN=&&TEMP02,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=VIO,SPACE=(TRK,(5,1))
//SYSTMP03 DD DSN=&&TEMP03,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=VIO,SPACE=(TRK,(5,1))
//SYSTMP04 DD DSN=&&TEMP04,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=VIO,SPACE=(TRK,(5,1))
//SYSTMP05 DD DSN=&&TEMP05,DISP=(NEW,DELETE,DELETE),
//            DCB=(RECFM=FBS,LRECL=23476),
//            UNIT=VIO,SPACE=(TRK,(5,1))
