/* 
 * Licensed Materials - Property of IBM and/or HCL 
 * (c) Copyright IBM Corporation 2005, 2021. All Rights Reserved. 
 * (c) Copyright HCL Technologies Ltd. 2017,2021. All Rights Reserved. 
 *  
 * Note to U.S. Government Users Restricted Rights: 
 * Use, duplication or disclosure restricted by GSA ADP Schedule 
 * Contract with IBM Corp.
 *
 */
#ifndef __XMLDHI_HPP
#define __XMLDHI_HPP

#include "shredder.hpp"
#include <xercesc/framework/XMLDocumentHandler.hpp>
#include <xercesc/parsers/SAXParser.hpp>

XERCES_CPP_NAMESPACE_BEGIN

/////////////////////////////////////////////////////////////////////////////
//
// Globals

#define ANY_SIZE  -1
#define MAX_UINT  4294967295
#ifdef __MVS__
  #undef PAGE_SIZE
  #define PAGE_SIZE 1048576
#else
	#undef PAGE_SIZE
	#define PAGE_SIZE 1048576
#endif
#define MAX_PATH 1024

#if defined(WIN32)
  #define int64_t __int64
#elif defined(UNIX)
  #define int64_t long long
#endif

static unsigned int gMaxSize = ANY_SIZE;

static const XMLCh gBundle[] =
{
  chLatin_B, chLatin_u, chLatin_n, chLatin_d, chLatin_l, chLatin_e, chNull
};

static const XMLCh gBundle_Source[] =
{
  chLatin_B, chLatin_u, chLatin_n, chLatin_d, chLatin_l, chLatin_e, chUnderscore, chLatin_S, chLatin_o, chLatin_u, chLatin_r, chLatin_c, chLatin_e, chNull
};

static const XMLCh gOpenAngleSlash[] =
{
  chOpenAngle, chForwardSlash, chNull
};

static const XMLCh gColon[] =
{
  chColon, chNull
};

static const XMLCh gCloseAngle[] =
{
  chCloseAngle, chNull
};

static const XMLCh gPain_001_001_02[] =
{
  chLatin_p, chLatin_a, chLatin_i, chLatin_n, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_2, chNull
};

static const XMLCh gPain_002_001_02[] =
{
  chLatin_p, chLatin_a, chLatin_i, chLatin_n, chPeriod, chDigit_0, chDigit_0, chDigit_2, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_2, chNull
};

static const XMLCh gPain_007_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_i, chLatin_n, chPeriod, chDigit_0, chDigit_0, chDigit_7, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

static const XMLCh gPain_008_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_i, chLatin_n, chPeriod, chDigit_0, chDigit_0, chDigit_8, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

static const XMLCh gPacs_002_001_02[] =
{
  chLatin_p, chLatin_a, chLatin_c, chLatin_s, chPeriod, chDigit_0, chDigit_0, chDigit_2, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_2, chNull
};

static const XMLCh gPacs_003_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_c, chLatin_s, chPeriod, chDigit_0, chDigit_0, chDigit_3, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

static const XMLCh gPacs_004_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_c, chLatin_s, chPeriod, chDigit_0, chDigit_0, chDigit_4, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

static const XMLCh gPacs_006_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_c, chLatin_s, chPeriod, chDigit_0, chDigit_0, chDigit_6, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

static const XMLCh gPacs_007_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_c, chLatin_s, chPeriod, chDigit_0, chDigit_0, chDigit_7, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

static const XMLCh gPacs_008_001_01[] =
{
  chLatin_p, chLatin_a, chLatin_c, chLatin_s, chPeriod, chDigit_0, chDigit_0, chDigit_8, chPeriod, chDigit_0, chDigit_0, chDigit_1, chPeriod, chDigit_0, chDigit_1, chNull
};

/////////////////////////////////////////////////////////////////////////////
//
// Class XMLDocumentHandlerImpl

class XMLDocumentHandlerImpl : public XMLDocumentHandler
{
public:
  XMLDocumentHandlerImpl();
  virtual ~XMLDocumentHandlerImpl();

  // XMLDocumentHandler interface implementation ////////////////////////////
  //
  /** Receive notification of character data.
    *
    * <p>The scanner will call this method to report each chunk of
    * character data. The scanner may return all contiguous character
    * data in a single chunk, or they may split it into several
    * chunks; however, all of the characters in any single event
    * will come from the same external entity, so that the Locator
    * provides useful information.</p>
    *
    * <p>The parser must not attempt to read from the array
    * outside of the specified range.</p>
    *
    * @param  chars           The content (characters) between markup from the XML
    *                         document.
    * @param  length          The number of characters to read from the array.
    * @param  cdataSection    Indicates that this data is inside a CDATA
    *                         section.
    */
  void docCharacters(
      const XMLCh* const chars
    , const unsigned int length
    , const bool cdataSection);

  /** Receive notification of comments in the XML content being parsed.
    *
    * This scanner will call this method for any comments found in the
    * content of the document.
    *
    * @param comment The text of the comment.
    */
  void docComment(
    const XMLCh* const comment);

  /** Receive notification of PI's parsed in the XML content.
    *
    * The scanner will call this method for any PIs it finds within the
    * content of the document.
    *
    * @param  target  The name of the PI.
    * @param  data    The body of the PI. This may be an empty string since
    *                 the body is optional.
    */
  void docPI(
      const XMLCh* const target
    , const XMLCh* const data);

  /** Receive notification after the scanner has parsed the end of the
    * document.
    *
    * The scanner will call this method when the current document has been
    * fully parsed. The handler may use this opportunity to do something with
    * the data, clean up temporary data, etc...
    */
  void endDocument();

  /** Receive notification of the end of an element.
    *
    * This method is called when scanner encounters the end of element tag.
    * There will be a corresponding startElement() event for every
    * endElement() event, but not necessarily the other way around. For
    * empty tags, there is only a startElement() call.
    *
    * @param  elemDecl The name of the element whose end tag was just
    *                     parsed.
    * @param  uriId       The ID of the URI in the URI pool (only valid if
    *                     name spaces is enabled)
    * @param  isRoot      Indicates if this is the root element.
    * @param  prefixName  The string representing the prefix name
    */
  void endElement(
      const XMLElementDecl& elemDecl
    , const unsigned int uriId
    , const bool isRoot
    , const XMLCh* const prefixName);

  /** Receive notification when a referenced entity's content ends
    *
    * This method is called when scanner encounters the end of an entity
    * reference.
    *
    * @param  entDecl  The name of the entity reference just scanned.
    */
  void endEntityReference(
      const XMLEntityDecl& entDecl);

  /** Receive notification of ignorable whitespace in element content.
    *
    * <p>Validating Parsers must use this method to report each chunk
    * of ignorable whitespace (see the W3C XML 1.0 recommendation,
    * section 2.10): non-validating parsers may also use this method
    * if they are capable of parsing and using content models.</p>
    *
    * <p>The scanner may return all contiguous whitespace in a single
    * chunk, or it may split it into several chunks; however, all of
    * the characters in any single event will come from the same
    * external entity, so that the Locator provides useful
    * information.</p>
    *
    * <p>The parser must not attempt to read from the array
    * outside of the specified range.</p>
    *
    * @param  chars       The whitespace characters from the XML document.
    * @param  length      The number of characters to read from the array.
    * @param  cdataSection Indicates that this data is inside a CDATA
    *                     section.
    * @see #characters
    */
  void ignorableWhitespace(
      const XMLCh* const chars
    , const unsigned int length
    , const bool cdataSection);

  /** Reset the document handler's state, if required
    *
    * This method is used to give the registered document handler a
    * chance to reset itself. Its called by the scanner at the start of
    * every parse.
    */
  void resetDocument();

  /** Receive notification of the start of a new document
    *
    * This method is the first callback called the scanner at the
    * start of every parse. This is before any content is parsed.
    */
  void startDocument();

  /** Receive notification of a new start tag
    *
    * This method is called when scanner encounters the start of an element tag.
    * All elements must always have a startElement() tag. Empty tags will
    * only have the startElement() tag and no endElement() tag.
    *
    * @param  elemDecl The name of the element whose start tag was just
    *                     parsed.
    * @param  uriId       The ID of the URI in the URI pool (only valid if
    *                     name spaces is enabled)
    * @param  prefixName  The string representing the prefix name
    * @param  attrList    List of attributes in the element
    * @param  attrCount   Count of the attributes in the element
    * @param  isEmpty     Indicates if the element is empty, in which case
    *                     you should not expect an endElement() event.
    * @param  isRoot      Indicates if this is the root element.
    */
  void startElement(
      const XMLElementDecl& elemDecl
    , const unsigned int uriId
    , const XMLCh* const prefixName
    , const RefVectorOf<XMLAttr>& attrList
    , const unsigned int attrCount
    , const bool isEmpty
    , const bool isRoot);

  /** Receive notification when the scanner hits an entity reference.
    *
    * This is currently useful only to DOM parser configurations as SAX
    * does not provide any api to return this information.
    *
    * @param  entDecl  The name of the entity that was referenced.
    */
  void startEntityReference(
      const XMLEntityDecl& entDecl);

  /** Receive notification of an XML declaration
    *
    * Currently neither DOM nor SAX provide API's to return back this
    * information.
    *
    * @param  versionStr      The value of the <code>version</code> pseudoattribute
    *                         of the XML decl.
    * @param  encodingStr     The value of the <code>encoding</code> pseudoattribute
    *                         of the XML decl.
    * @param  standaloneStr   The value of the <code>standalone</code>
    *                         pseudoattribute of the XML decl.
    * @param  autoEncodingStr The encoding string auto-detected by the
    *                         scanner. In absence of any 'encoding' attribute in the
    *                         XML decl, the XML standard specifies how a parser can
    *                         auto-detect. If there is no <code>encodingStr</code>
    *                         this is what will be used to try to decode the file.
    */
  void XMLDecl(
      const XMLCh* const versionStr
    , const XMLCh* const encodingStr
    , const XMLCh* const standaloneStr
    , const XMLCh* const autoEncodingStr);

/////////////////////////////////////////////////////////////////////////////
// Methods

public:
  /** parse
    *
    * @param  xmlUrl
    * @param  maxSize
    * @param  errMsg
    */
  unsigned int parse(
      const char* xmlUrl
    , unsigned int maxSize
    , char* errMsg);

protected:
  InputSource* getInputSource(
      const char* url);

  /** getFileName
   *
   * @param  sourceFileName
   */
  void getFileName(
      char* sourceFileName);

  /** writeFile
   *
   * @param  toWrite
   * @param  writeHeader
   * @param  writeTrailer
   */
  void writeFile(
      unsigned int toWrite
    , bool writeHeader = true
    , bool writeTrailer = true);

  /** checkElementName
   *
   * @param  toCheck
   */
  bool checkElementName(
      const XMLCh* toCheck);

/////////////////////////////////////////////////////////////////////////////
// Data members

protected:
  SAXParser* fParser;
  XMLCh* fSourceFileName;
  FileHandle fSourceFile;
  FileHandle fBundleFile;
  XMLCh* fEncoding;

  XMLByte* fHeaderBuff;
  unsigned int fHeaderBuffSize;
  XMLByte* fTrailerBuff;
  unsigned int fTrailerBuffSize;
  XMLByte* fContentBuff;

  unsigned long fCount;
  int64_t fMaxSize;
  int64_t fCurrentOffset;
  bool fPayloadHasStarted;
};

// checkElementName /////////////////////////////////////////////////////////

inline bool XMLDocumentHandlerImpl::checkElementName(
    const XMLCh* toCheck)
{
  if (!toCheck)
    return false;
  
  if (XMLString::compareString(toCheck, gPacs_002_001_02) == 0 ||
      XMLString::compareString(toCheck, gPacs_004_001_01) == 0 ||
      XMLString::compareString(toCheck, gPacs_003_001_01) == 0 ||
      XMLString::compareString(toCheck, gPacs_006_001_01) == 0 ||
      XMLString::compareString(toCheck, gPacs_007_001_01) == 0 ||
      XMLString::compareString(toCheck, gPacs_008_001_01) == 0 ||
      XMLString::compareString(toCheck, gPain_001_001_02) == 0 ||
      XMLString::compareString(toCheck, gPain_002_001_02) == 0 ||
      XMLString::compareString(toCheck, gPain_007_001_01) == 0 ||
      XMLString::compareString(toCheck, gPain_008_001_01) == 0)
    return true;
  else
    return false;
}

XERCES_CPP_NAMESPACE_END

#endif // __XMLDHI_HPP
