@echo off
REM ***************************************************************************
REM *
REM *  Licensed Materials - Property of IBM and/or HCL
REM *  (c) Copyright IBM Corporation 2005, 2021. All Rights Reserved.
REM *  (c) Copyright HCL Technologies Ltd. 2017, 2021. All Rights Reserved.
REM *
REM *  Note to U.S. Government Users Restricted Rights:
REM *  Use, duplication or disclosure restricted by GSA ADP Schedule
REM *  Contract with IBM Corp.
REM *
REM *
REM *  This batch file compiles all maps for the SWIFT LMF transformation.
REM *  After the map build, the deployment step performs an FTP copy of all of
REM *  the files needed for the system to run.
REM *
REM *  There are 5 parameters needed for this script to execute.
REM *  Any or all of these parameters can be set through command line,
REM *  or can be hard-coded in the set values below.
REM *
REM *  This batch file takes 5 parameters:
REM *  1 = OS Platform: AIX, HPUX, SOLARIS, ZOS, LINUX, ZLINUX, HPITANIUM or WINDOWS
REM *  2 = Operating system user name (if no user name is given, then it is assumed
REM *      the deployment step is not required, and parameters 3 - 5 will not be needed.
REM *  3 = Operating system password
REM *  4 = FTP Server location
REM *  5 = top level directory to deploy map files, schemas, and supporting files
REM *
REM *  NOTE: The script is designed to use paths without spaces for parameter 5.
REM *  Further modification is needed to this script and the ftp template script
REM *   if path names with spaces is to be used.
REM *
REM *  NOTE: For parameter 5, under this top level directory specified, the files
REM *  will be deployed to a sub folder called mt, and distributed to other
REM *  folders underneath this mt folder.
REM *
REM *  EXAMPLE call to the script with all parameters passed:
REM *  build_deploy_lmf.bat AIX user password UNIXMACHINE /usr/apps/base/packs/swift
REM *
REM ***************************************************************************

set dash=-------------------------------------------------------

rem set OS platform - parameter 1
set deploy=true
set PLATFORM=%1
if not defined   PLATFORM    goto :Error_PlatformNotSpecified

rem - set FTP location's OS user account and password. Parameters 2 and 3
set USER=%2
if not defined   USER    goto :no_deploy_params_setup

set PASSWORD=%3
if not defined   PASSWORD    goto :Error_PasswordNotSpecified

rem set FTP server location - Parameter 4
set FTP_SERVER=%4
if not defined   FTP_SERVER    goto :Error_ServerNotSpecified

rem - set target directory for deployment. Parameter 5
set baseDIR=%5
if not defined   baseDIR    goto :Error_PathNotSpecified

if defined USER    goto :skip_no_deploy_params

:no_deploy_params_setup
set deploy=false

:skip_no_deploy_params

set LOG=build_deploy_lmf.log
rem - clear out old log file...
if exist %LOG% del /f /q %LOG%
rem - create new log file and header for specific base version...
echo Build and Deploying Pack for Financial Payments - SWIFT Component MT-LMF conversion on %PLATFORM% > %LOG%
echo FTP Server: %FTP_SERVER% >> %LOG%
echo Using directory: %baseDIR% >> %LOG%
echo %dash% >> %LOG%
echo Start time is: >> %LOG%
time /T >> %LOG%
DATE /T >> %LOG%
echo %dash% >> %LOG%

rem cd to the directory this batch file is running from
rem cd /d %~dp0 - use this if the pushd doesn't work
pushd "%~dp0"

set LMFDir=%CD%
echo base Pack for SWIFT LMF directory is: %CD% >> %LOG%

rem cd to the base directory to get the location of mcompile.exe
cd ..\..\..\..\..\

rem check to make sure mcompile is where we expect it
if exist "%CD%\mcompile.exe" (
    set DTX_HOME=%CD%
	) else (
	goto :MCompileNotFound
)

rem set up the directories for all of the files that need to be moved
cd "%LMFDir%"

rem create a directory to hold all of the files that will be deployed

if not exist "%LMFDir%\deployment_lmf" (
	mkdir deployment_lmf
	mkdir deployment_lmf\maps
	)

set DeployDir=%LMFDir%\deployment_lmf

cd %LMFDir%

rem *********************************MAP BUILD**************************************
echo *********************************MAP BUILD************************************** >> %LOG%
echo deployment directory is:  %DeployDir% >> %LOG%
echo DTX_HOME is: %DTX_HOME% >> %LOG%
echo.
echo %dash%
echo === Starting map build...
echo.
set MCOMPILE="%DTX_HOME%\mcompile.exe"
echo mcompile.exe location is: %MCOMPILE% >> %LOG%
set mcompileOptions= -P %PLATFORM% -A -E -O "%DeployDir%\maps\*.mmc"
echo === Starting build of "from_lmf" maps...
echo.
%MCOMPILE% from_lmf\swift_ca_event_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf\swift_mt101_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf\swift_mt102_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt103_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt202_COV_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt202_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt205_COV_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt205_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt210_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt300_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt304_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt305_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt320_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt502_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt509_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt515_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt535_fromlmf.mms %mcompileOptions% >> %LOG%
echo === continuing "from_lmf" maps build...
%MCOMPILE% from_lmf/swift_mt536_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt537_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt548_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt549_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt578_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt900_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt910_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt940_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt942_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mt950_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mtn90_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mtn91_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mtn92_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mtn95_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_mtn96_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_settconf_mt54x_fromlmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% from_lmf/swift_settinst_mt54x_fromlmf.mms %mcompileOptions% >> %LOG%
echo.
echo === Finished "from_lmf" map build.
echo === Finished "from_lmf" map build. >> %LOG%
echo.
echo === Starting build of "to_lmf" maps...
echo.

%MCOMPILE% to_lmf/swift_mt101_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt102_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt103_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt202_COV_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt202_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt205_COV_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt205_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt210_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt300_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt304_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt305_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt320_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt502_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt509_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt515_tolmf.mms %mcompileOptions% >> %LOG%
echo === continuing "to_lmf" maps build...
%MCOMPILE% to_lmf/swift_mt535_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt536_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt537_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt548_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt549_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt564_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt565_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt566_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt567_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt568_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt578_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt900_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt910_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt940_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt942_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mt950_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mtn90_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mtn91_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mtn92_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mtn95_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_mtn96_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_settconf_mt54x_tolmf.mms %mcompileOptions% >> %LOG%
%MCOMPILE% to_lmf/swift_settinst_mt54x_tolmf.mms %mcompileOptions% >> %LOG%
echo.
echo === Finished "to_lmf" map build.
echo === Finished "to_lmf" map build. >> %LOG%
echo.

if %deploy% == false goto :skipDeploy
rem ********************************DEPLOYMENT**************************************
echo *********************************DEPLOYMENT************************************* >> %LOG%
echo.
echo %dash%
echo.
echo === Starting deployment...
echo.

rem ============================================================================
rem :DeployToUnix
rem create the ftp script to run with the user name, password and server
rem to copy all artifacts to remote servers
rem ============================================================================

:DeployToUnix

echo Preparing FTP script to deploy all SWIFT LMF artifacts to %PLATFORM% - %FTP_SERVER%...
call :BatchSubstitute "#FTP_SERVER#" %FTP_SERVER% FTP_unix_deploy_lmf.template.scp > start.scp
call :BatchSubstitute "#USER#" %USER% start.scp > user.scp
del start.scp
call :BatchSubstitute "#PASSWORD#" %PASSWORD% user.scp > pw.scp
del user.scp
call :BatchSubstitute "#SERVERHOME#" %baseDIR% pw.scp > basedir.scp
del pw.scp
for %%f in ("%DeployDir%") do set ShortMapDir=%%~sf
call :BatchSubstitute "#DEPLOYDIR#" %ShortMapDir% basedir.scp > deploy.scp
del basedir.scp

echo Created temporary FTP script. >> %LOG%

echo Running FTP script to deploy all SWIFT LMF artifacts to %PLATFORM% - %FTP_SERVER%...
echo Running FTP script to deploy all SWIFT LMF artifacts to %PLATFORM% - %FTP_SERVER%... >> %LOG%

REM ===========================================================================
REM If using Secure FTP, uncomment out the next line and modify according to
REM your SFTP client command line options.
REM ===========================================================================
REM psftp %USER%@%FTP_SERVER% -pw %PASSWORD% -bc -be -b deploy.scp >> %LOG%

ftp -s:deploy.scp  >> %LOG%

REM ===========================================================================
REM for troubleshooting FTP issues, comment out the next line and
REM analyze the file deploy.scp
REM ===========================================================================
del deploy.scp

goto :Run_EXIT

rem ============================================================================
rem :BatchSubstitute
rem  Text string find/replace.
rem ============================================================================

:BatchSubstitute

REM -- Prepare the Command Processor --
setLOCAL ENABLEEXTENSIONS
setLOCAL DISABLEDELAYEDEXPANSION

if "%*"=="" findstr "^::" "%~f0"&GOTO:EOF
for /f "tokens=1,* delims=]" %%A in ('"type %3|find /n /v """') do (
    set "line=%%B"
    if defined line (
        call set "line=echo.%%line:%~1=%~2%%"
        for /f "delims=" %%X in ('"echo."%%line%%""') do %%~X
    ) ELSE echo.
)

goto :EOF

:Error_UserNotSpecified
set ERROR=No OS User specified.
goto :Print_Error

:Error_PasswordNotSpecified
set ERROR=No OS Password specified.
goto :Print_Error

:Error_PlatformNotSpecified
set ERROR=No OS Platform specified.
goto :Print_Error

:Error_ServerNotSpecified
set ERROR=No FTP Server location specified.
goto :Print_Error

:Error_PathNotSpecified
set ERROR=No top level directory specified.
goto :Print_Error

:Print_Error
echo.
echo %dash%
echo Error: %ERROR%
echo %dash%
goto :Print_Params

:Print_Params
echo.
echo This batch file takes 5 parameters:
echo.
echo 1 = OS Platform: AIX, HPUX, SOLARIS, ZOS, LINUX, ZLINUX, HPITANIUM or WINDOWS
echo.
echo 2 = Operating system user name
echo.
echo 3 = Operating system password
echo.
echo 4 = FTP Server location
echo.
echo 5 = top level directory to deploy map files, schemas, and supporting files
echo.
echo EXAMPLE: build_deploy_lmf.bat AIX username password  UNIXMACHINE /usr/bin/base/packs/swift
goto :EOF

:MCompileNotFound
echo %dash%
echo.
echo base directory not found!
echo This script must run from the SWIFT component default installation subdirectory: mt\lmf.
echo Example: "<base product install dir>\packs\financial_payments_v<version>\swift\mt\lmf"
echo.
echo %dash%
goto :EOF

:skipDeploy
echo Skipping FTP deployment of all SWIFT MT LMF artifacts...
echo Skipping FTP deployment of all SWIFT MT LMF artifacts... >> %LOG%

:Run_EXIT

echo %dash%
echo === Map compile and deploy script completed
echo.
echo === The log of actions titled build_deploy_lmf.log is located at %CD%
echo %dash%
goto :EOF
